aboutsummaryrefslogtreecommitdiff
path: root/src/meta1lex.h
diff options
context:
space:
mode:
authorSergey Poznyakoff <gray@gnu.org.ua>2009-10-12 21:14:00 +0300
committerSergey Poznyakoff <gray@gnu.org.ua>2009-10-12 21:14:00 +0300
commitaf04ed630f18e9003756317cc627a11084d0d59a (patch)
tree828cf1fc2c326842777942441c14e853d9894cc7 /src/meta1lex.h
parent989a5bbb74c3620abaa2191ce2c4f8d5968dbf0a (diff)
downloadpies-af04ed630f18e9003756317cc627a11084d0d59a.tar.gz
pies-af04ed630f18e9003756317cc627a11084d0d59a.tar.bz2
Do not require Mailutils. Provide missing functions.
* Makefile.am (ACLOCAL_AMFLAGS): Add grecs/am * bootstrap.conf: Skip po. Initialize submodule. * configure.ac: Mailutils no longer needed. (AC_CONFIG_FILES): Add new subdirs. * gnulib.modules: Add more modules. Arrange entries alphabetically. * lib/Makefile.am: Rename library to libpies. * lib/libpies.h (mf_privs) (switch_to_privs, get_user_groups) (mf_priv_setup, mf_epriv_setup): Move to src/pies.h (config_array_to_argv, config_array_to_string) (config_cb_timeout): Remove. (tokendef): New struct. (strtotok_len, strtotok_len_ci) (strtotok, strtotok_ci, toktostr): New prototypes. * lib/nls.c: Remove call to mu_init_nls. * src/acl.c: New file. * src/addrfmt.c: New file. * src/diag.c: New file. * src/meta.c: New file. * src/url.c: New file. * src/userprivs.c: New file. * src/acl.h: New file. * src/pp-setup: New file. * src/Makefile.am (pies_SOURCES): Add acl.c, addrfmt.c, diag.c, meta.c, url.c, userprivs.c. (noinst_HEADERS): Add acl.h. (inc_DATA): Add pp-setup. * src/limits.c, src/meta1gram.y, src/meta1lex.h, src/meta1lex.l, src/pies.c, src/pies.h, src/progman.c, src/socket.c, src/userprivs.c: Remove calls to functions from Mailutils.
Diffstat (limited to 'src/meta1lex.h')
-rw-r--r--src/meta1lex.h14
1 files changed, 6 insertions, 8 deletions
diff --git a/src/meta1lex.h b/src/meta1lex.h
index 8db32f9..035204b 100644
--- a/src/meta1lex.h
+++ b/src/meta1lex.h
@@ -1,23 +1,21 @@
-/* This file is part of Mailfromd.
- Copyright (C) 2008 Sergey Poznyakoff
+/* This file is part of Pies.
+ Copyright (C) 2009, 2009 Sergey Poznyakoff
- This program is free software; you can redistribute it and/or modify
+ Pies is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.
- This program is distributed in the hope that it will be useful,
+ Pies is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
- along with this program. If not, see <http://www.gnu.org/licenses/>. */
+ along with Pies. If not, see <http://www.gnu.org/licenses/>. */
-extern mu_cfg_locus_t meta1_locus;
+extern grecs_locus_t meta1_locus;
extern size_t meta1_error_count;
-extern mu_cfg_node_t *meta1_parse_head;
-extern mu_cfg_tree_t *meta1_parse_tree;
extern char *meta1_queue_dir;
char *meta1_string (const char *str, size_t len);

Return to:

Send suggestions and report system problems to the System administrator.